When monitor(port-mirroring) traffic from other lacp port-channel,
rx_machine_update may recieving other lacp negotiation packets.
Thus bond mode 4 will negotiation failed.

Fixes: 112891cd27e5 ("net/bonding: add dedicated HW queues for LACP control")
Cc: sta...@dpdk.org

Signed-off-by: Liang Zhang <zhangli...@bigo.sg>
---
 drivers/net/bonding/rte_eth_bond_8023ad.c         | 12 ++++++++++--
 drivers/net/bonding/rte_eth_bond_8023ad_private.h |  1 +
 2 files changed, 11 insertions(+), 2 deletions(-)

diff --git a/drivers/net/bonding/rte_eth_bond_8023ad_private.h 
b/drivers/net/bonding/rte_eth_bond_8023ad_private.h
index c16dba8..dbdf581 100644
--- a/drivers/net/bonding/rte_eth_bond_8023ad_private.h
+++ b/drivers/net/bonding/rte_eth_bond_8023ad_private.h
@@ -179,6 +179,7 @@ struct mode8023ad_private {
        uint64_t update_timeout_us;
        rte_eth_bond_8023ad_ext_slowrx_fn slowrx_cb;
        uint8_t external_sm;
+       struct ether_addr mac_addr;
 
        /**
         * Configuration of dedicated hardware queues for control plane
diff --git a/drivers/net/bonding/rte_eth_bond_8023ad.c 
b/drivers/net/bonding/rte_eth_bond_8023ad.c
index a2313b3..40f2921 100644
--- a/drivers/net/bonding/rte_eth_bond_8023ad.c
+++ b/drivers/net/bonding/rte_eth_bond_8023ad.c
@@ -757,13 +757,20 @@ static void
 rx_machine_update(struct bond_dev_private *internals, uint8_t slave_id,
                struct rte_mbuf *lacp_pkt) {
        struct lacpdu_header *lacp;
+       struct lacpdu_actor_partner_params *partner;
 
        if (lacp_pkt != NULL) {
                lacp = rte_pktmbuf_mtod(lacp_pkt, struct lacpdu_header *);
                RTE_ASSERT(lacp->lacpdu.subtype == SLOW_SUBTYPE_LACP);
 
-               /* This is LACP frame so pass it to rx_machine */
-               rx_machine(internals, slave_id, &lacp->lacpdu);
+               partner = &lacp->lacpdu.partner;
+               if (is_same_ether_addr(&partner->port_params.system,
+                       &internals->mode4.mac_addr)) {
+                       /* This LACP frame is sending to the bonding port
+                        * so pass it to rx_machine.
+                        */
+                       rx_machine(internals, slave_id, &lacp->lacpdu);
+               }
                rte_pktmbuf_free(lacp_pkt);
        } else
                rx_machine(internals, slave_id, NULL);
@@ -1171,6 +1178,7 @@ bond_mode_8023ad_start(struct rte_eth_dev *bond_dev)
        struct mode8023ad_private *mode4 = &internals->mode4;
        static const uint64_t us = BOND_MODE_8023AX_UPDATE_TIMEOUT_MS * 1000;
 
+       rte_eth_macaddr_get(internals->port_id, &mode4->mac_addr);
        if (mode4->slowrx_cb)
                return rte_eal_alarm_set(us, &bond_mode_8023ad_ext_periodic_cb,
                                         bond_dev);
-- 
2.7.4

Reply via email to